==> kmymoney_5.1.1.orig.tar.xz: kmymoney-5.1.1/kmymoney/plugins/views/budget/budgetview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "darren_gould@gmx.de",
                "Name": "Darren Gould",
                "Name[ca@valencia]": "Darren Gould",
                "Name[ca]": "Darren Gould",
                "Name[cs]": "Darren Gould",
                "Name[de]": "Darren Gould",
                "Name[en_GB]": "Darren Gould",
                "Name[es]": "Darren Gould",
                "Name[et]": "Darren Gould",
                "Name[eu]": "Darren Gould",
                "Name[fi]": "Darren Gould",
                "Name[fr]": "Darren Gould",
                "Name[gl]": "Darren Gould",
                "Name[ia]": "Darren Gould",
                "Name[it]": "Darren Gould",
                "Name[ko]": "Darren Gould",
                "Name[nl]": "Darren Gould",
                "Name[pl]": "Darren Gould",
                "Name[pt]": "Darren Gould",
                "Name[pt_BR]": "Darren Gould",
                "Name[ru]": "Darren Gould",
                "Name[sk]": "Darren Gould",
                "Name[sv]": "Darren Gould",
                "Name[uk]": "Darren Gould",
                "Name[x-test]": "xxDarren Gouldxx"
            }
        ],
        "Description": "Adds budget view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista del pressupost al KMyMoney",
        "Description[ca]": "Afegeix la vista del pressupost al KMyMoney",
        "Description[en_GB]": "Adds budget view to KMyMoney",
        "Description[es]": "Añade la vista de presupuestos a KMyMoney",
        "Description[et]": "KMyMoney eelarvevaade",
        "Description[eu]": "Aurrekontu ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn budjettinäkymän",
        "Description[fr]": "Ajoute la vue Budget à KMyMoney",
        "Description[gl]": "Engade unha vista de presuposto a KMyMoney",
        "Description[it]": "Aggiunge la vista dei budget a KMyMoney",
        "Description[ko]": "KMyMoney에 예산 보기 추가",
        "Description[nl]": "Voegt weergave van budgetten toe aan KMyMoney",
        "Description[pl]": "Dodaje widok budżetów do KMyMoney",
        "Description[pt]": "Adiciona a área do orçamento ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de orçamento no KMyMoney",
        "Description[sk]": "Pridá pohľad rozpočtu do KMyMoney",
        "Description[sv]": "Lägger till budgetvy i KMyMoney",
        "Description[uk]": "Панель бюджетів у KMyMoney",
        "Description[x-test]": "xxAdds budget view to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "budget",
        "Id": "budgetview",
        "License": "GPL",
        "Name": "Budget view",
        "Name[ca@valencia]": "Vista de pressupost",
        "Name[ca]": "Vista de pressupost",
        "Name[de]": "Budgetansicht",
        "Name[en_GB]": "Budget view",
        "Name[es]": "Vista de presupuestos",
        "Name[et]": "Eelarvevaade",
        "Name[eu]": "Aurrekontu ikuspegia",
        "Name[fi]": "Budjettinäkymä",
        "Name[fr]": "Vue Budget",
        "Name[gl]": "Vista de presuposto",
        "Name[it]": "Vista dei budget",
        "Name[ko]": "예산 보기",
        "Name[nl]": "Budgetweergave",
        "Name[pl]": "Widok budżetu",
        "Name[pt]": "Área do Orçamento",
        "Name[pt_BR]": "Área de orçamento",
        "Name[sk]": "Pohľad rozpočtu ",
        "Name[sv]": "Budgetvy",
        "Name[uk]": "Панель бюджету",
        "Name[x-test]": "xxBudget viewxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/views/budget/budgetview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "darren_gould@gmx.de",
                "Name": "Darren Gould",
                "Name[ca@valencia]": "Darren Gould",
                "Name[ca]": "Darren Gould",
                "Name[cs]": "Darren Gould",
                "Name[de]": "Darren Gould",
                "Name[en_GB]": "Darren Gould",
                "Name[es]": "Darren Gould",
                "Name[et]": "Darren Gould",
                "Name[eu]": "Darren Gould",
                "Name[fi]": "Darren Gould",
                "Name[fr]": "Darren Gould",
                "Name[gl]": "Darren Gould",
                "Name[ia]": "Darren Gould",
                "Name[it]": "Darren Gould",
                "Name[ko]": "Darren Gould",
                "Name[nl]": "Darren Gould",
                "Name[pl]": "Darren Gould",
                "Name[pt]": "Darren Gould",
                "Name[pt_BR]": "Darren Gould",
                "Name[ru]": "Darren Gould",
                "Name[sk]": "Darren Gould",
                "Name[sl]": "Darren Gould",
                "Name[sv]": "Darren Gould",
                "Name[uk]": "Darren Gould",
                "Name[x-test]": "xxDarren Gouldxx",
                "Name[zh_CN]": "Darren Gould"
            }
        ],
        "Description": "Adds budget view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista del pressupost al KMyMoney",
        "Description[ca]": "Afegeix la vista del pressupost al KMyMoney",
        "Description[en_GB]": "Adds budget view to KMyMoney",
        "Description[es]": "Añade la vista de presupuestos a KMyMoney",
        "Description[et]": "KMyMoney eelarvevaade",
        "Description[eu]": "Aurrekontu ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn budjettinäkymän",
        "Description[fr]": "Ajoute la vue Budget à KMyMoney",
        "Description[gl]": "Engade unha vista de presuposto a KMyMoney",
        "Description[it]": "Aggiunge la vista dei budget a KMyMoney",
        "Description[ko]": "KMyMoney에 예산 보기 추가",
        "Description[nl]": "Voegt weergave van budgetten toe aan KMyMoney",
        "Description[pl]": "Dodaje widok budżetów do KMyMoney",
        "Description[pt]": "Adiciona a área do orçamento ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de orçamento no KMyMoney",
        "Description[sk]": "Pridá pohľad rozpočtu do KMyMoney",
        "Description[sl]": "Doda proračunski pogled v KMyMoney",
        "Description[sv]": "Lägger till budgetvy i KMyMoney",
        "Description[uk]": "Панель бюджетів у KMyMoney",
        "Description[x-test]": "xxAdds budget view to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加预算视图",
        "EnabledByDefault": true,
        "Icon": "budget",
        "Id": "budgetview",
        "License": "GPL",
        "Name": "Budget view",
        "Name[ca@valencia]": "Vista de pressupost",
        "Name[ca]": "Vista de pressupost",
        "Name[de]": "Budgetansicht",
        "Name[en_GB]": "Budget view",
        "Name[es]": "Vista de presupuestos",
        "Name[et]": "Eelarvevaade",
        "Name[eu]": "Aurrekontu ikuspegia",
        "Name[fi]": "Budjettinäkymä",
        "Name[fr]": "Vue Budget",
        "Name[gl]": "Vista de presuposto",
        "Name[it]": "Vista dei budget",
        "Name[ko]": "예산 보기",
        "Name[nl]": "Budgetweergave",
        "Name[pl]": "Widok budżetu",
        "Name[pt]": "Área do Orçamento",
        "Name[pt_BR]": "Área de orçamento",
        "Name[sk]": "Pohľad rozpočtu ",
        "Name[sl]": "Pogled na proračun",
        "Name[sv]": "Budgetvy",
        "Name[uk]": "Панель бюджету",
        "Name[x-test]": "xxBudget viewxx",
        "Name[zh_CN]": "预算视图",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
